==> FHLBBS-5.1.tgz: php/post.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","currboard","cbrd","comment1","title1");
   $postfile=new dirrec;
   $t1 = time();
   $t2 = date("D M d H:i:s Y");
   /**** BzD ***/
   $title1=trim($_REQUEST["title1"]);
   if (strlen($title1)==0) $title1="LD....";
   $currboard=trim($_REQUEST["board1"]);
   /***** BzHp ***/
   $localsave=(int) $_REQUEST["LOCALSAVE"];
   /********** BzñW ******/
   $signyn=(int) $_REQUEST["SIGNYN"];
   if ($signyn==0) $sign=0;
   else
   	$sign=(int) $_REQUEST["SIGNFILE"];
   if ($sign<0) $sign=0;
   elseif ($sign>9) $sign=9;
   /**** Mw̫̥h ***/
   $where=(int) $_REQUEST["WHERE"];
   /**** MwOO H ***/
   $target=(int) $_REQUEST["TARGET"];
   /****B̬O_ۯdZ ******/
   $backupmail=(int) $_REQUEST["backupmail"];
   if (strrchr($currboard,'/')) //ȬOhacker
      die ("<h1>AOhackerܡH</h1><p>\n");

   /*** @̾ ***/
   $remotehost=$REMOTE_ADDR;
   $comment1= $_REQUEST["comment1"];
   $message=str_replace("\"","\"",$message);
   if (strlen($comment1)==0) die("eOŪIiKѡI");
   $buf1= $_REQUEST["submit1"];
   if (strstr($buf1,"w")!==false) $postmode=1; //wҦ
   else $postmode=0;
	
   $name1=$cuser->userid; /*** nOiYɪuserid **/
   $name2=$cuser->userid; /*** gJ峹}Yuser id **/
   if ($target==0)
   {
      $cbrd=searchbrd($currboard);
      if ((!$cbrd)||(!Ben_Perm($cbrd)))
           die("S $currboard oӰQװϡI<p>\n");

      /*******  ΦW ********/
      if (strcmp($currboard,"Anonymity")==0) 
      { 
 	$name1="";
        $name2="anonymous";
        $postname="@ADڬO";
	$remotehost="Wa";
        $signyn=0;
      }
      else
        $postname=$cuser->username;
      $currmode=0;
      if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM($cbrd->BM)))
      {
	     $currmode |= (MODE_BOARD | MODE_POST);
      } 
      elseif (haspostperm($cbrd)) $currmode |= MODE_POST;

      if (!(($currmode)&(MODE_POST)))
         die("藍_AzثeLkbo峹I<p>\n");
   } 
   if ($postmode)
   {
      echo "<HTML><HEAD>\n";
      echo "<TITLE>wzҽs誺G</TITLE>\n";
      echo "<font size=5 color=\"#ff0000\"><center>zoepU</center></font>\n";
      echo "<hr>\n";
      echo "<table>\n";
   }
   if ($postmode==0)
    {
      $filename2="M.{$t1}.A";
      
      if ($target==1) /** H ***/
	  {
   	    $receiver=trim($_REQUEST["RECEIVER"]);
	    $filename1=sethomefile($receiver,$filename2);
	    if (($fptr2 = fopen($filename1,"w"))===false)
		die ("S{$receiver}oӤHI<p>\n");
	    $genbuf=sprintf("@: %s(%s)\n",$name1,$cuser->username);
	    fwrite($fptr2,$genbuf);
	  }
      else /** Qװ **/
	  {
	    $filename1=$BBSHOME."/boards/{$currboard}/{$filename2}";
	    if (($fptr2 = fopen($filename1,"w"))===false)
		die ("$filename1 ɮ׶}ҿ~I\n");
            $genbuf=sprintf("@: %s(%s) ݪO: %s\n",$name2,$postname,$currboard);
	    fwrite($fptr2,$genbuf);
	  }
      fwrite($fptr2,"D: {$title1}\n");
      fwrite($fptr2,"ɶ: {$t2}\n\n");
      fwrite($fptr2,$comment1);
      /**** ñW ***/
      if ($signyn==1)
      {
	$buf1=sethomefile($cuser->userid,"sig.{$sign}");
	if ((is_file($buf1))&&(($fptr1 = fopen($buf1,"r"))!==false))
        { 
	  fwrite($fptr2,"\n--\n");
	  fwrite($fptr2,fread($fptr1,filesize($buf1)));//gXh
          fclose($fptr1);
        }
      } 
      /*** 峹  **/
      fwrite($fptr2, "{$END_TITLE} From: {$remotehost}\n");
      fclose($fptr2);
    } 
    else /** w **/
    {
      if ($target==1)
	 echo "@: {$name1}({$cuser->username})<br>\n";
      else
         echo "@: {$name2}({$postname}) ݪO: {$currboard}<br>\n";
      echo "D: {$title1}<br>\n";
      echo "ɶ: {$t2}<br>\n";
      echo "<pre>";
      echo htmlspecialchars($comment1);
      if ($signyn)
      {
	$buf1=sethomefile($cuser->userid,"sig.{$sign}");
        if (is_file($buf1)&&($fptr1 = fopen($buf1,"r"))!==false)
        {
            echo "\n--\n";
            echo fread($fptr1,filesize($buf1));//gXh
            fclose($fptr1);
        }
      } 
      echo "{$END_TITLE} From: {$remotehost}\n</pre></table>\n<hr>\n"; 
      echo "<form method=\"POST\" action=\"{$PHP_SELF}\"\n>";
      if ($target==1) 
      {
	$receiver=trim($_REQUEST["RECEIVER"]);
        echo "<input type=\"hidden\" name=\"RECEIVER\" value=\"{$receiver}\">\n";
        if ($backupmail)
        	echo "<input type=\"checkbox\" name=\"backupmail\" value=1 checked>nۦsZ";
	else
        	echo "<input type=\"checkbox\" name=\"backupmail\" value=1>nۦsZ";
      }
      else
        echo "<input type=\"hidden\" name=\"LOCALSAVE\" value=\"{$localsave}\">\n";
      echo "&nbsp;&nbsp;&nbsp;<input type=\"submit\" name=\"submit1\" value=\"iK\">";
      echo "&nbsp;&nbsp;&nbsp;<a href=\"Javascript:history.go(-1)\">~s</a>";
      echo "<input type=\"hidden\" name=\"WHERE\" value=\"{$where}\">\n";
      echo "<input type=\"hidden\" name=\"title1\" value=\"{$title1}\">\n";
      echo "<input type=\"hidden\" name=\"TARGET\" value=\"{$target}\">\n";
      echo "<input type=\"hidden\" name=\"SIGNYN\" value=\"{$signyn}\">\n";
      echo "<input type=\"hidden\" name=\"SIGNFILE\" value=\"{$sign}\">\n";
      echo "<input type=\"hidden\" name=\"board1\" value=\"{$currboard}\">\n";
      echo "<input type=\"hidden\" name=\"comment1\" value=\"{$comment1}\">\n</form></td>";
      echo "</form>";
      echo "</body></html>\n";
      die();
    }

   $postfile->filename=$filename2;
   $postfile->owner=$name1;
   $postfile->title=$title1;

   if (HAS_PERM(PERM_INTERNET) && $localsave) 
   	$postfile->savemode='S'; //H
   else $postfile->savemode='L'; //
    
   /*** gY ***/
   $postfile->date=date("n/d");
   if (strlen($postfile->date)==4) $postfile->date=" ".$postfile->date;
   if ($target==1)
	$buf1=sethomedir($receiver);
   else
	$buf1=$BBSHOME."/boards/{$currboard}/.DIR";
   $numposts = (int) filesize($buf1)/$dirlength;
   $postfile->substitute_record($buf1,$numposts+1);
   /***** pGOHAӥBnۦsZ ***********/
   if (($target==1) && ($backupmail==1))
   {
	$filename3=sethomefile($cuser->userid,$filename2);
	link($filename1,$filename3);
	$buf1=sethomedir($cuser->userid);
        $postfile->owner="[..]";
        $postfile->title="({$receiver}) $title1";
   	$numposts = (int) filesize($buf1)/$dirlength;
   	$postfile->substitute_record($buf1,$numposts+1);
   }
   $comment1="";
   $title1="";

  /*********  iK\ *****/
   if (($target==0)&&($postmode==0)) //`postQװ
   {
       /**** OwgŪLF **/
      $brc=new ubrcrec;
      $brc->brc_initial($currboard);
      $brc->brc_addlist($postfile->filename);
      $brc->brc_update();
      $cuser->numposts=$cuser->numposts+1;
      /****BzñWɶ*****/
      $cuser->uflag = (((int) $cuser->uflag) & ~SIG_FLAG) | ($sign & SIG_FLAG);
      $uid=searchuser($cuser->userid);
      if ($uid>0)
           $cuser->substitute_record($PASSWD_FILE,$uid);
      else die("register numberpost  fail!!!\n");
      $location1=$BBSHOME."/boards/{$currboard}/wpostnum";
      logcnt($location1);
   }
   /**** Isphp **/
   if ($where==1)
	header("Location: mlist.php");
   else
	header("Location: boards.php?{$currboard}");

   /** HXh **/
   if (($target==0)&&(HAS_PERM(PERM_INTERNET))&& $localsave)
   {
     $buf1="{$BBSHOME}/innd/out.bntp";
     if (($fptr1 = fopen($buf1, "a"))!==false){
        $genbuf=sprintf("%s\t%s\t%s\t%s\t%s\n", $currboard,
        $filename2, $name1,"FROM.FHLWBBS", $title1);
	fwrite($fptr1,$genbuf);
        fclose($fptr1);
     }
   }
?>

==> FHLBBS-5.3.tgz: php/post.php <==
<?php
 require("config.php");
 require("wbbs.php");
 require("auth.php");
 session_register("userid","cuser","currboard","cbrd","comment1","title1");
   $postfile=new dirrec;
   $t1 = time();
   $t2 = date("D M d H:i:s Y");
   /**** BzD ***/
   $title1=trim($_REQUEST["title1"]);
   if (strlen($title1)==0) $title1="LD....";
   $currboard=trim($_REQUEST["board1"]);
   /***** BzHp ***/
   $localsave=(int) $_REQUEST["LOCALSAVE"];
   /********** BzñW ******/
   $signyn=(int) $_REQUEST["SIGNYN"];
   if ($signyn==0) $sign=0;
   else
   	$sign=(int) $_REQUEST["SIGNFILE"];
   if ($sign<0) $sign=0;
   elseif ($sign>9) $sign=9;
   /**** Mw̫̥h ***/
   $where=(int) $_REQUEST["WHERE"];
   /**** MwOO H ***/
   $target=(int) $_REQUEST["TARGET"];
   /****B̬O_ۯdZ ******/
   $backupmail=(int) $_REQUEST["backupmail"];
   if (strrchr($currboard,'/')) //ȬOhacker
      die ("<h1>AOhackerܡH</h1><p>\n");

   /*** @̾ ***/
   $remotehost=$REMOTE_ADDR;
   $comment1= $_REQUEST["comment1"];
   $message=str_replace("\"","\"",$message);
   if (strlen($comment1)==0) die("eOŪIiKѡI");
   $buf1= $_REQUEST["submit1"];
   if (strstr($buf1,"w")!==false) $postmode=1; //wҦ
   else $postmode=0;
	
   $name1=$cuser->userid; /*** nOiYɪuserid **/
   $name2=$cuser->userid; /*** gJ峹}Yuser id **/
   if ($target==0)
   {
      $cbrd=searchbrd($currboard);
      if ((!$cbrd)||(!Ben_Perm($cbrd)))
           die("S $currboard oӰQװϡI<p>\n");

      /*******  ΦW ********/
      if (strcmp($currboard,"Anonymity")==0) 
      { 
 	$name1="";
        $name2="anonymous";
        $postname="@ADڬO";
	$remotehost="Wa";
        $signyn=0;
      }
      else
        $postname=$cuser->username;
      $currmode=0;
      if (HAS_PERM(PERM_ALLBOARD) || (HAS_PERM(PERM_BM) && is_BM($cbrd->BM)))
      {
	     $currmode |= (MODE_BOARD | MODE_POST);
      } 
      elseif (haspostperm($cbrd)) $currmode |= MODE_POST;

      if (!(($currmode)&(MODE_POST)))
         die("藍_AzثeLkbo峹I<p>\n");
   } 
   if ($postmode)
   {
      echo "<HTML><HEAD>\n";
      echo "<TITLE>wzҽs誺G</TITLE>\n";
      echo "<font size=5 color=\"#ff0000\"><center>zoepU</center></font>\n";
      echo "<hr>\n";
      echo "<table>\n";
   }
   if ($postmode==0)
    {
      $filename2="M.{$t1}.A";
      
      if ($target==1) /** H ***/
	  {
   	    $receiver=trim($_REQUEST["RECEIVER"]);
	    $filename1=sethomefile($receiver,$filename2);
	    if (($fptr2 = fopen($filename1,"w"))===false)
		die ("S{$receiver}oӤHI<p>\n");
	    $genbuf=sprintf("@: %s(%s)\n",$name1,$cuser->username);
	    fwrite($fptr2,$genbuf);
	  }
      else /** Qװ **/
	  {
	    $filename1=$BBSHOME."/boards/{$currboard}/{$filename2}";
	    if (($fptr2 = fopen($filename1,"w"))===false)
		die ("$filename1 ɮ׶}ҿ~I\n");
            $genbuf=sprintf("@: %s(%s) ݪO: %s\n",$name2,$postname,$currboard);
	    fwrite($fptr2,$genbuf);
	  }
      fwrite($fptr2,"D: {$title1}\n");
      fwrite($fptr2,"ɶ: {$t2}\n\n");
      fwrite($fptr2,$comment1);
      /**** ñW ***/
      if ($signyn==1)
      {
	$buf1=sethomefile($cuser->userid,"sig.{$sign}");
	if ((is_file($buf1))&&(($fptr1 = fopen($buf1,"r"))!==false))
        { 
	  fwrite($fptr2,"\n--\n");
	  fwrite($fptr2,fread($fptr1,filesize($buf1)));//gXh
          fclose($fptr1);
        }
      } 
      /*** 峹  **/
      fwrite($fptr2, "{$END_TITLE} From: {$remotehost}\n");
      fclose($fptr2);
    } 
    else /** w **/
    {
      if ($target==1)
	 echo "@: {$name1}({$cuser->username})<br>\n";
      else
         echo "@: {$name2}({$postname}) ݪO: {$currboard}<br>\n";
      $htitle1=htmlspecialchars($title1);
      echo "D: {$htitle1}<br>\n";
      echo "ɶ: {$t2}<br>\n";
      echo "<pre>";
      $hcomment1=htmlspecialchars($comment1);
      echo $hcomment1;
      if ($signyn)
      {
	$buf1=sethomefile($cuser->userid,"sig.{$sign}");
        if (is_file($buf1)&&($fptr1 = fopen($buf1,"r"))!==false)
        {
            echo "\n--\n";
            echo fread($fptr1,filesize($buf1));//gXh
            fclose($fptr1);
        }
      } 
      echo "{$END_TITLE} From: {$remotehost}\n</pre></table>\n<hr>\n"; 
      echo "<form method=\"POST\" action=\"{$PHP_SELF}\"\n>";
      if ($target==1) 
      {
	$receiver=trim($_REQUEST["RECEIVER"]);
        echo "<input type=\"hidden\" name=\"RECEIVER\" value=\"{$receiver}\">\n";
        if ($backupmail)
        	echo "<input type=\"checkbox\" name=\"backupmail\" value=1 checked>nۦsZ";
	else
        	echo "<input type=\"checkbox\" name=\"backupmail\" value=1>nۦsZ";
      }
      else
        echo "<input type=\"hidden\" name=\"LOCALSAVE\" value=\"{$localsave}\">\n";
      echo "&nbsp;&nbsp;&nbsp;<input type=\"submit\" name=\"submit1\" value=\"iK\">";
      echo "&nbsp;&nbsp;&nbsp;<a href=\"Javascript:history.go(-1)\">~s</a>";
      echo "<input type=\"hidden\" name=\"WHERE\" value=\"{$where}\">\n";
      echo "<input type=\"hidden\" name=\"title1\" value=\"{$htitle1}\">\n";
      echo "<input type=\"hidden\" name=\"TARGET\" value=\"{$target}\">\n";
      echo "<input type=\"hidden\" name=\"SIGNYN\" value=\"{$signyn}\">\n";
      echo "<input type=\"hidden\" name=\"SIGNFILE\" value=\"{$sign}\">\n";
      echo "<input type=\"hidden\" name=\"board1\" value=\"{$currboard}\">\n";
      echo "<input type=\"hidden\" name=\"comment1\" value=\"{$hcomment1}\">\n</form></td>";
      echo "</form>";
      echo "</body></html>\n";
      die();
    }

   $postfile->filename=$filename2;
   $postfile->owner=$name1;
   $postfile->title=$title1;

   if (HAS_PERM(PERM_INTERNET) && $localsave) 
   	$postfile->savemode='S'; //H
   else $postfile->savemode='L'; //
    
   /*** gY ***/
   $postfile->date=date("n/d");
   if (strlen($postfile->date)==4) $postfile->date=" ".$postfile->date;
   if ($target==1)
	$buf1=sethomedir($receiver);
   else
	$buf1=$BBSHOME."/boards/{$currboard}/.DIR";
   $numposts = (int) filesize($buf1)/$dirlength;
   $postfile->substitute_record($buf1,$numposts+1);
   /***** pGOHAӥBnۦsZ ***********/
   if (($target==1) && ($backupmail==1))
   {
	$filename3=sethomefile($cuser->userid,$filename2);
	link($filename1,$filename3);
	$buf1=sethomedir($cuser->userid);
        $postfile->owner="[..]";
        $postfile->title="({$receiver}) $title1";
   	$numposts = (int) filesize($buf1)/$dirlength;
   	$postfile->substitute_record($buf1,$numposts+1);
   }
   $comment1="";
   $title1="";

  /*********  iK\ *****/
   if (($target==0)&&($postmode==0)) //`postQװ
   {
       /**** OwgŪLF **/
      $brc=new ubrcrec;
      $brc->brc_initial($currboard);
      $brc->brc_addlist($postfile->filename);
      $brc->brc_update();
      $cuser->numposts=$cuser->numposts+1;
      /****BzñWɶ*****/
      $cuser->uflag = (((int) $cuser->uflag) & ~SIG_FLAG) | ($sign & SIG_FLAG);
      $uid=searchuser($cuser->userid);
      if ($uid>0)
           $cuser->substitute_record($PASSWD_FILE,$uid);
      else die("register numberpost  fail!!!\n");
      $location1=$BBSHOME."/boards/{$currboard}/wpostnum";
      logcnt($location1);
   }
   /**** Isphp **/
   if ($where==1)
	header("Location: mlist.php");
   else
	header("Location: boards.php?{$currboard}");
   /** HXh **/
   if (($target==0)&&(HAS_PERM(PERM_INTERNET))&& $localsave)
   {
     $buf1="{$BBSHOME}/innd/out.bntp";
     if (($fptr1 = fopen($buf1, "a"))!==false){
        $genbuf=sprintf("%s\t%s\t%s\t%s\t%s\n", $currboard,
        $filename2, $name1,$cuser->username, $postfile->title);
	fwrite($fptr1,$genbuf);
        fclose($fptr1);
     }
   }
?>
